window.Gleam.initSearch([{"doc":"glitzer","title":"glitzer","content":"&lt;h1 align=&quot;center&quot;&gt;\n  &lt;a href=&quot;https://github.com/miampf/glitzer&quot;&gt;\n    &lt;!-- Please provide path to your logo here --&gt;\n    &lt;img src=&quot;https://raw.githubusercontent.com/miampf/glitzer/main/docs/images/logo.svg&quot; alt=&quot;Logo&quot; width=&quot;100&quot; height=&quot;100&quot;&gt;\n  &lt;/a&gt;\n&lt;/h1&gt;\n\n&lt;div align=&quot;center&quot;&gt;\n  glitzer - make your projects :sparkles: sparkle :sparkles:\n  &lt;br /&gt;\n  &lt;br /&gt;\n  &lt;a href=&quot;https://github.com/miampf/glitzer/issues/new?assignees=&amp;labels=bug&amp;template=01_BUG_REPORT.md&amp;title=bug%3A+&quot;&gt;Report a Bug&lt;/a&gt;\n  ·\n  &lt;a href=&quot;https://github.com/miampf/glitzer/issues/new?assignees=&amp;labels=enhancement&amp;template=02_FEATURE_REQUEST.md&amp;title=feat%3A+&quot;&gt;Request a Feature&lt;/a&gt;\n  .\n  &lt;a href=&quot;https://github.com/miampf/glitzer/issues/new?assignees=&amp;labels=question&amp;template=04_SUPPORT_QUESTION.md&amp;title=support%3A+&quot;&gt;Ask a Question&lt;/a&gt;\n&lt;/div&gt;\n\n&lt;div align=&quot;center&quot;&gt;\n&lt;br /&gt;\n\n[![Pull Requests welcome](https://img.shields.io/badge/PRs-welcome-ff69b4.svg?style=flat-square)](https://github.com/miampf/glitzer/issues?q=is%3Aissue+is%3Aopen+label%3A%22help+wanted%22)\n[![code with love by miampf](https://img.shields.io/badge/%3C%2F%3E%20with%20%E2%99%A5%20by-miampf-ff1414.svg?style=flat-square)](https://github.com/miampf)\n\n[![Package Version](https://img.shields.io/hexpm/v/glitzer?style=flat-square)](https://hex.pm/packages/glitzer)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3?style=flat-square)](https://hexdocs.pm/glitzer/)\n\n&lt;/div&gt;\n\n&lt;details open=&quot;open&quot;&gt;\n&lt;summary&gt;Table of Contents&lt;/summary&gt;\n\n- [About](#about)\n- [Getting Started](#getting-started)\n  - [Installation](#installation)\n- [Usage](#usage)\n  - [A simple progress bar](#a-simple-progress-bar)\n  - [Progress bar templates](#progress-bar-templates)\n- [Roadmap](#roadmap)\n- [Support](#support)\n- [Project assistance](#project-assistance)\n- [Contributing](#contributing)\n- [License](#license)\n- [Acknowledgements](#acknowledgements)\n\n&lt;/details&gt;\n\n---\n\n## About\n\nGlitzer (german for &quot;glitter&quot; or &quot;sparkle&quot;) is a library for gleam that helps\nyou create progress bars and other fancy progress reporting and command line\nutilities. It is written in pure gleam and supports javascript and erlang.\n\n&lt;img src=&quot;https://raw.githubusercontent.com/miampf/glitzer/main/docs/images/example.gif&quot; width=&quot;100%&quot;&gt;\n\n## Getting Started\n\n### Installation\n\nSimply run\n\n```sh\ngleam add glitzer\n```\n\nin your projects root directory to add the library to your project.\n\n## Usage\n\nYou can access the progress bars with `import glitzer/progress`.\n\n### A simple progress bar\n\n```gleam\nimport gleam/int\nimport gleam/iterator\n\nimport glitzer/progress\n\npub fn main() {\n    let bar = \n        progress.new_bar() \n        |&gt; progress.with_length(100)\n        |&gt; progress.with_fill(progress.char_from_string(&quot;+&quot;))\n        |&gt; progress.with_empty(progress.char_from_string(&quot;-&quot;))\n        |&gt; progress.with_left_text(&quot;Doing stuff: &quot;)\n    iterator.range(1, 100)\n    |&gt; progress.each_iterator(bar, fn(bar, i) {\n        progress.with_left_text(bar, int.to_string(i) &lt;&gt; &quot; &quot;)\n        |&gt; progress.print_bar\n        // do some other stuff here\n    })\n}\n```\n\n### Progress bar templates\n\nGlitzer also provides some premade templates for progress bars. All of these\ntemplates have a default length of 100. As an example, here is how you could use\nthe `fancy_slim_arrow_bar` template.\n\n```gleam\nimport glitzer/progress\n\npub fn main() {\n    let bar = progress.fancy_slim_arrow_bar()\n    do_stuff(bar, 0)\n}\n\nfn do_stuff(bar, count) {\n    case count &lt; 100 {\n       True -&gt; {\n            let bar = progress.tick(bar)\n            progress.print_bar(bar)\n            // some heavy lifting\n            do_stuff(bar, count + 1)\n        }\n       False -&gt; Nil \n    }\n}\n```\n\nAll templates can be found in the\n[documentation](https://hexdocs.pm/glitzer/glitzer/progress.html)\n\n### Spinners\n\nImport spinners into your project using `import glitzer/spinner`.\n\n```gleam\nimport glitzer/spinner\n\npub fn main() {\n  let s =\n    spinner.default_spinner()\n    |&gt; spinner.with_left_text(&quot;Imma spin &gt;:3 &quot;)\n    |&gt; spinner.with_finish_text(&quot;I&#39;m dizzy :(&quot;)\n    |&gt; spinner.spin // this will continuously spin your spinner\n\n    // do some stuff\n    \n    // update the text\n    spinner.with_left_text(s, &quot;Now imma spin some more :] &quot;)\n    |&gt; spinner.with_frame_transform(fn(s) {&quot;&lt;&quot; &lt;&gt; s &lt;&gt; &quot;&gt;&quot;})\n\n    spinner.finish(s) // clear the line and print the finish text\n}\n```\n\n## Roadmap\n\nSee the [open issues](https://github.com/miampf/glitzer/issues) for a list of\nproposed features (and known issues).\n\n- [Top Feature Requests](https://github.com/miampf/glitzer/issues?q=label%3Aenhancement+is%3Aopen+sort%3Areactions-%2B1-desc)\n  (Add your votes using the 👍 reaction)\n- [Top Bugs](https://github.com/miampf/glitzer/issues?q=is%3Aissue+is%3Aopen+label%3Abug+sort%3Areactions-%2B1-desc)\n  (Add your votes using the 👍 reaction)\n- [Newest Bugs](https://github.com/miampf/glitzer/issues?q=is%3Aopen+is%3Aissue+label%3Abug)\n\n## Support\n\nNew code and pull requests are greatly appreciated! If you want to contribute,\ncheck the [contributing guidelines](#contributing) and submit a PR :3\n\nIf you have any questions, feel free to\n[create a question]((https://github.com/miampf/glitzer/issues/new?assignees=&amp;labels=question&amp;template=04_SUPPORT_QUESTION.md&amp;title=support%3A+))!\nPlease note that it may take some time for me to respond. I am not paid for\ndoing this and do have a private life (surprise!) :]\n\nIf something is very urgent, you may\n[write me an email](mailto:miampf@proton.me). However, only do this if it&#39;s\nsomething major like a security issue or harassement in some discussion of the\nproject. Harassement does not mean someone not agreeing with your point of view\nabout the project.\n\n## Project assistance\n\nIf you want to say **thank you** or/and support active development of glitzer,\nfeel free to add a [GitHub Star](https://github.com/miampf/glitzer) to the\nproject!\n\n## Contributing\n\nFirst off, thanks for taking the time to contribute! Contributions are what make\nthe open-source community such an amazing place to learn, inspire, and create.\nAny contributions you make will benefit everybody else and are **greatly\nappreciated**.\n\nPlease read [our contribution guidelines](docs/CONTRIBUTING.md), and thank you\nfor being involved!\n\n## License\n\nThis project is licensed under the **GNU General Public License v3**.\n\nSee [LICENSE](LICENSE) for more information.\n\n## Acknowledgements\n\n- [indicatif](https://github.com/console-rs/indicatif) greatly inspired this\n  project!\n- [spinner](https://github.com/lpil/spinner) is a very cool gleam library to\n  create simple spinners. If you don&#39;t need more than that, check them out!\n","url":"index.html"},{"doc":"glitzer/codes","title":"clear_line_code","content":"pub const clear_line_code: String\n Print this code to clear the current line.\nSynonyms:\nglitzer/codes.clear_line_code\nglitzer/codes clear_line_code","url":"glitzer/codes.html#clear_line_code"},{"doc":"glitzer/codes","title":"clear_screen_code","content":"pub const clear_screen_code: String\n Print this code to clear the whole screen.\nSynonyms:\nglitzer/codes.clear_screen_code\nglitzer/codes clear_screen_code","url":"glitzer/codes.html#clear_screen_code"},{"doc":"glitzer/codes","title":"hide_cursor_code","content":"pub const hide_cursor_code: String\n Print this code to hide the cursor\nSynonyms:\nglitzer/codes.hide_cursor_code\nglitzer/codes hide_cursor_code","url":"glitzer/codes.html#hide_cursor_code"},{"doc":"glitzer/codes","title":"return_home_code","content":"pub const return_home_code: String\n Print this code to return the cursor to the &quot;home&quot; position.\nSynonyms:\nglitzer/codes.return_home_code\nglitzer/codes return_home_code","url":"glitzer/codes.html#return_home_code"},{"doc":"glitzer/codes","title":"return_line_start_code","content":"pub const return_line_start_code: String\n Print this code to return to the start of the line\nSynonyms:\nglitzer/codes.return_line_start_code\nglitzer/codes return_line_start_code","url":"glitzer/codes.html#return_line_start_code"},{"doc":"glitzer/codes","title":"show_cursor_code","content":"pub const show_cursor_code: String\n Print this code to show the cursor if it has been hidden\nSynonyms:\nglitzer/codes.show_cursor_code\nglitzer/codes show_cursor_code","url":"glitzer/codes.html#show_cursor_code"},{"doc":"glitzer/codes","title":"glitzer/codes","content":"","url":"glitzer/codes.html"},{"doc":"glitzer/progress","title":"Char","content":"pub opaque type Char\n A `String` with only one character.\n\nSynonyms:\nglitzer/progress.Char\nglitzer/progress Char","url":"glitzer/progress.html#Char"},{"doc":"glitzer/progress","title":"ProgressStyle","content":"pub opaque type ProgressStyle\n The style of a progress bar.\n\nSynonyms:\nglitzer/progress.ProgressStyle\nglitzer/progress ProgressStyle","url":"glitzer/progress.html#ProgressStyle"},{"doc":"glitzer/progress","title":"State","content":"pub opaque type State\n\n\nSynonyms:\nglitzer/progress.State\nglitzer/progress State","url":"glitzer/progress.html#State"},{"doc":"glitzer/progress","title":"char_from_string","content":"pub fn char_from_string(from in: String) -&gt; Char\n Create a `Char` from a `String`. Returns a `Char` with the given string if\n the strings length is equal to one and a `Char` of &quot;#&quot; otherwise.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import glitzer/progress\n\n fn example() {\n   let char = progress.char_from_string(&quot;A&quot;)\n }\n \n\n &lt;/details&gt;\nSynonyms:\nglitzer/progress.char_from_string\nglitzer/progress char_from_string","url":"glitzer/progress.html#char_from_string"},{"doc":"glitzer/progress","title":"default_bar","content":"pub fn default_bar() -&gt; ProgressStyle\n Create and return a default progress bar.\nSynonyms:\nglitzer/progress.default_bar\nglitzer/progress default_bar","url":"glitzer/progress.html#default_bar"},{"doc":"glitzer/progress","title":"each_iterator","content":"pub fn each_iterator(\n  over i: Iterator(a),\n  bar bar: ProgressStyle,\n  with fun: fn(ProgressStyle, a) -&gt; b,\n) -&gt; Nil\n\nSynonyms:\nglitzer/progress.each_iterator\nglitzer/progress each_iterator","url":"glitzer/progress.html#each_iterator"},{"doc":"glitzer/progress","title":"fancy_slim_arrow_bar","content":"pub fn fancy_slim_arrow_bar() -&gt; ProgressStyle\n Create and return a fancy and slim progress bar with an arrow head.\nSynonyms:\nglitzer/progress.fancy_slim_arrow_bar\nglitzer/progress fancy_slim_arrow_bar","url":"glitzer/progress.html#fancy_slim_arrow_bar"},{"doc":"glitzer/progress","title":"fancy_slim_bar","content":"pub fn fancy_slim_bar() -&gt; ProgressStyle\n Create and return a fancy and slim progress bar (inspired by pip).\nSynonyms:\nglitzer/progress.fancy_slim_bar\nglitzer/progress fancy_slim_bar","url":"glitzer/progress.html#fancy_slim_bar"},{"doc":"glitzer/progress","title":"fancy_thick_bar","content":"pub fn fancy_thick_bar() -&gt; ProgressStyle\n Create and return a fancy thick bar.\nSynonyms:\nglitzer/progress.fancy_thick_bar\nglitzer/progress fancy_thick_bar","url":"glitzer/progress.html#fancy_thick_bar"},{"doc":"glitzer/progress","title":"finish","content":"pub fn finish(bar bar: ProgressStyle) -&gt; ProgressStyle\n Completely fill the progress bar.\nSynonyms:\nglitzer/progress.finish\nglitzer/progress finish","url":"glitzer/progress.html#finish"},{"doc":"glitzer/progress","title":"map2_iterator","content":"pub fn map2_iterator(\n  iterator1 i1: Iterator(a),\n  iterator2 i2: Iterator(b),\n  bar bar: ProgressStyle,\n  with fun: fn(ProgressStyle, a, b) -&gt; c,\n) -&gt; Iterator(c)\n\nSynonyms:\nglitzer/progress.map2_iterator\nglitzer/progress map2_iterator","url":"glitzer/progress.html#map2_iterator"},{"doc":"glitzer/progress","title":"map_iterator","content":"pub fn map_iterator(\n  over i: Iterator(a),\n  bar bar: ProgressStyle,\n  with fun: fn(ProgressStyle, a) -&gt; b,\n) -&gt; Iterator(b)\n Map an iterator to a function with a bar that ticks every run of the\n function.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import glitzer/progress\n\n fn example(bar) {\n   iterator.range(0, 100)\n   |&gt; progress.map_iterator(fn(bar, element) {\n     progress.print_bar(bar)\n     // do some heavy calculations here &gt;:)\n   })\n }\n \n\n &lt;/details&gt;\nSynonyms:\nglitzer/progress.map_iterator\nglitzer/progress map_iterator","url":"glitzer/progress.html#map_iterator"},{"doc":"glitzer/progress","title":"new_bar","content":"pub fn new_bar() -&gt; ProgressStyle\n Create a new (completely empty) progress bar.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import glitzer/progress\n\n fn example() {\n   let bar = \n     progress.new_bar()\n     |&gt; progress.with_length(50)\n     |&gt; progress.with_left_text(&quot;Progress: &quot;)\n     |&gt; progress.with_fill(progress.char_from_string(&quot;+&quot;))\n }\n \n\n &lt;/details&gt;\nSynonyms:\nglitzer/progress.new_bar\nglitzer/progress new_bar","url":"glitzer/progress.html#new_bar"},{"doc":"glitzer/progress","title":"print_bar","content":"pub fn print_bar(bar bar: ProgressStyle) -&gt; Nil\n Print the progress bar to stderr.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import glitzer/progress\n\n fn example() {\n   let bar = progress.default_bar()\n\n   run_example(bar, 0)\n }\n\n fn run_example(bar, count) {\n   case count &lt; 100 {\n     True -&gt; {\n       let bar = progress.tick(bar)\n       // do some awesome stuff :3\n       progress.print_bar(bar)\n       run_example(bar, count + 1)\n     }\n     False -&gt; Nil\n   }\n }\n \n\n &lt;/details&gt;\nSynonyms:\nglitzer/progress.print_bar\nglitzer/progress print_bar","url":"glitzer/progress.html#print_bar"},{"doc":"glitzer/progress","title":"slim_bar","content":"pub fn slim_bar() -&gt; ProgressStyle\n Create and return a fancy and slim progress bar (inspired by pip).\nSynonyms:\nglitzer/progress.slim_bar\nglitzer/progress slim_bar","url":"glitzer/progress.html#slim_bar"},{"doc":"glitzer/progress","title":"string_from_char","content":"pub fn string_from_char(from in: Char) -&gt; String\n Create a `String` from a given `Char`.\nSynonyms:\nglitzer/progress.string_from_char\nglitzer/progress string_from_char","url":"glitzer/progress.html#string_from_char"},{"doc":"glitzer/progress","title":"thick_bar","content":"pub fn thick_bar() -&gt; ProgressStyle\n Create and return a thick bar.\nSynonyms:\nglitzer/progress.thick_bar\nglitzer/progress thick_bar","url":"glitzer/progress.html#thick_bar"},{"doc":"glitzer/progress","title":"tick","content":"pub fn tick(bar bar: ProgressStyle) -&gt; ProgressStyle\n Increase the progress of the bar by one.\nSynonyms:\nglitzer/progress.tick\nglitzer/progress tick","url":"glitzer/progress.html#tick"},{"doc":"glitzer/progress","title":"tick_by","content":"pub fn tick_by(bar bar: ProgressStyle, i i: Int) -&gt; ProgressStyle\n Increase the progress of the bar by `i`.\nSynonyms:\nglitzer/progress.tick_by\nglitzer/progress tick_by","url":"glitzer/progress.html#tick_by"},{"doc":"glitzer/progress","title":"with_empty","content":"pub fn with_empty(\n  bar bar: ProgressStyle,\n  empty char: Char,\n) -&gt; ProgressStyle\n Add a character to a progress bar that is used to represent the\n &quot;background&quot; of the bar.\nSynonyms:\nglitzer/progress.with_empty\nglitzer/progress with_empty","url":"glitzer/progress.html#with_empty"},{"doc":"glitzer/progress","title":"with_fill","content":"pub fn with_fill(\n  bar bar: ProgressStyle,\n  fill char: Char,\n) -&gt; ProgressStyle\n Add a character to a progress bar that is used to fill the bar on each\n tick.\nSynonyms:\nglitzer/progress.with_fill\nglitzer/progress with_fill","url":"glitzer/progress.html#with_fill"},{"doc":"glitzer/progress","title":"with_fill_finished","content":"pub fn with_fill_finished(\n  bar bar: ProgressStyle,\n  fill char: Char,\n) -&gt; ProgressStyle\n Add a character that will be used instead of `fill` if the bar is finished.\nSynonyms:\nglitzer/progress.with_fill_finished\nglitzer/progress with_fill_finished","url":"glitzer/progress.html#with_fill_finished"},{"doc":"glitzer/progress","title":"with_fill_head","content":"pub fn with_fill_head(\n  bar bar: ProgressStyle,\n  fill char: Char,\n) -&gt; ProgressStyle\n Add a head to the progress bar.\nSynonyms:\nglitzer/progress.with_fill_head\nglitzer/progress with_fill_head","url":"glitzer/progress.html#with_fill_head"},{"doc":"glitzer/progress","title":"with_fill_head_finished","content":"pub fn with_fill_head_finished(\n  bar bar: ProgressStyle,\n  fill char: Char,\n) -&gt; ProgressStyle\n Add a head to the progress bar that will be displayed when the bar\n finishes.\nSynonyms:\nglitzer/progress.with_fill_head_finished\nglitzer/progress with_fill_head_finished","url":"glitzer/progress.html#with_fill_head_finished"},{"doc":"glitzer/progress","title":"with_left_text","content":"pub fn with_left_text(\n  bar bar: ProgressStyle,\n  left text: String,\n) -&gt; ProgressStyle\n Add left text to a progress bar.\nSynonyms:\nglitzer/progress.with_left_text\nglitzer/progress with_left_text","url":"glitzer/progress.html#with_left_text"},{"doc":"glitzer/progress","title":"with_length","content":"pub fn with_length(\n  bar bar: ProgressStyle,\n  length len: Int,\n) -&gt; ProgressStyle\n Add length to a progress bar.\nSynonyms:\nglitzer/progress.with_length\nglitzer/progress with_length","url":"glitzer/progress.html#with_length"},{"doc":"glitzer/progress","title":"with_right_text","content":"pub fn with_right_text(\n  bar bar: ProgressStyle,\n  right text: String,\n) -&gt; ProgressStyle\n Add right text to a progress bar.\nSynonyms:\nglitzer/progress.with_right_text\nglitzer/progress with_right_text","url":"glitzer/progress.html#with_right_text"},{"doc":"glitzer/progress","title":"glitzer/progress","content":"","url":"glitzer/progress.html"},{"doc":"glitzer/spinner","title":"Frames","content":"pub opaque type Frames\n\n\nSynonyms:\nglitzer/spinner.Frames\nglitzer/spinner Frames","url":"glitzer/spinner.html#Frames"},{"doc":"glitzer/spinner","title":"SpinnerStyle","content":"pub opaque type SpinnerStyle\n\n\nSynonyms:\nglitzer/spinner.SpinnerStyle\nglitzer/spinner SpinnerStyle","url":"glitzer/spinner.html#SpinnerStyle"},{"doc":"glitzer/spinner","title":"State","content":"pub opaque type State\n Contains everything that might get changed during runtime.\n\nSynonyms:\nglitzer/spinner.State\nglitzer/spinner State","url":"glitzer/spinner.html#State"},{"doc":"glitzer/spinner","title":"bar_left_right_spinner","content":"pub fn bar_left_right_spinner() -&gt; SpinnerStyle\n A spinner that goes from left to right and back.\nSynonyms:\nglitzer/spinner.bar_left_right_spinner\nglitzer/spinner bar_left_right_spinner","url":"glitzer/spinner.html#bar_left_right_spinner"},{"doc":"glitzer/spinner","title":"bar_up_down_spinner","content":"pub fn bar_up_down_spinner() -&gt; SpinnerStyle\n A spinner with a bar that goes up and down.\nSynonyms:\nglitzer/spinner.bar_up_down_spinner\nglitzer/spinner bar_up_down_spinner","url":"glitzer/spinner.html#bar_up_down_spinner"},{"doc":"glitzer/spinner","title":"default_spinner","content":"pub fn default_spinner() -&gt; SpinnerStyle\n The default spinner.\nSynonyms:\nglitzer/spinner.default_spinner\nglitzer/spinner default_spinner","url":"glitzer/spinner.html#default_spinner"},{"doc":"glitzer/spinner","title":"finish","content":"pub fn finish(spinner s: SpinnerStyle) -&gt; SpinnerStyle\n Finish a spinner. If it was countinously ticking, the ticking will be\n stopped. The line will be cleared and the finish text will be printed if\n the spinner had some.\nSynonyms:\nglitzer/spinner.finish\nglitzer/spinner finish","url":"glitzer/spinner.html#finish"},{"doc":"glitzer/spinner","title":"frames_from_list","content":"pub fn frames_from_list(frames frames: List(String)) -&gt; Frames\n Convert a given list of `String` to `Frames`.\nSynonyms:\nglitzer/spinner.frames_from_list\nglitzer/spinner frames_from_list","url":"glitzer/spinner.html#frames_from_list"},{"doc":"glitzer/spinner","title":"new_spinner","content":"pub fn new_spinner(frames f: Frames) -&gt; SpinnerStyle\n Create a new spinner from `Frames` with a 100ms tick rate.\nSynonyms:\nglitzer/spinner.new_spinner\nglitzer/spinner new_spinner","url":"glitzer/spinner.html#new_spinner"},{"doc":"glitzer/spinner","title":"prideful_spinner","content":"pub fn prideful_spinner() -&gt; SpinnerStyle\n A very colorful spinner with the colors from the progress pride flag :3\n Note that this spinner has a tick rate of 200 instead of 100 to not flash\n to fast.\nSynonyms:\nglitzer/spinner.prideful_spinner\nglitzer/spinner prideful_spinner","url":"glitzer/spinner.html#prideful_spinner"},{"doc":"glitzer/spinner","title":"print_spinner","content":"pub fn print_spinner(spinner s: SpinnerStyle) -&gt; Nil\n Print the spinner. This is useful if you need/want manual control over your\n spinner ticks and prints.\nSynonyms:\nglitzer/spinner.print_spinner\nglitzer/spinner print_spinner","url":"glitzer/spinner.html#print_spinner"},{"doc":"glitzer/spinner","title":"pulsating_spinner","content":"pub fn pulsating_spinner() -&gt; SpinnerStyle\n A spinner that pulsates.\nSynonyms:\nglitzer/spinner.pulsating_spinner\nglitzer/spinner pulsating_spinner","url":"glitzer/spinner.html#pulsating_spinner"},{"doc":"glitzer/spinner","title":"spin","content":"pub fn spin(spinner s: SpinnerStyle) -&gt; SpinnerStyle\n Continuously tick and print the spinner. Note that this **does not** update\n the tick value of your spinner reference!\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import glitzer/spinner\n\n fn example() {\n   spinner.default_spinner()\n   |&gt; spinner.spin\n }\n \n\n &lt;/details&gt;\nSynonyms:\nglitzer/spinner.spin\nglitzer/spinner spin","url":"glitzer/spinner.html#spin"},{"doc":"glitzer/spinner","title":"spinning_spinner","content":"pub fn spinning_spinner() -&gt; SpinnerStyle\n A spinner that actually spins.\nSynonyms:\nglitzer/spinner.spinning_spinner\nglitzer/spinner spinning_spinner","url":"glitzer/spinner.html#spinning_spinner"},{"doc":"glitzer/spinner","title":"tick","content":"pub fn tick(spinner s: SpinnerStyle) -&gt; SpinnerStyle\n Progress the spinner by one.\nSynonyms:\nglitzer/spinner.tick\nglitzer/spinner tick","url":"glitzer/spinner.html#tick"},{"doc":"glitzer/spinner","title":"tick_by","content":"pub fn tick_by(spinner s: SpinnerStyle, i i: Int) -&gt; SpinnerStyle\n Progress the spinner by `i`.\nSynonyms:\nglitzer/spinner.tick_by\nglitzer/spinner tick_by","url":"glitzer/spinner.html#tick_by"},{"doc":"glitzer/spinner","title":"with_finish_text","content":"pub fn with_finish_text(\n  spinner s: SpinnerStyle,\n  text t: String,\n) -&gt; SpinnerStyle\n Set the spinners finish text.\nSynonyms:\nglitzer/spinner.with_finish_text\nglitzer/spinner with_finish_text","url":"glitzer/spinner.html#with_finish_text"},{"doc":"glitzer/spinner","title":"with_frame_transform","content":"pub fn with_frame_transform(\n  spinner s: SpinnerStyle,\n  transform fun: fn(String) -&gt; String,\n) -&gt; SpinnerStyle\n Set a transformation function that will be applied for each frame. This can\n be every function with the signature `fn(String) -&gt; String`.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import glitzer/spinner\n import gleam_community/ansi\n\n fn example() {\n   let s =\n     spinner.default_spinner()\n     |&gt; spinner.with_frame_transform(ansi.pink) // make all frames pink\n     |&gt; spinner.spin\n\n   // do some cool stuff\n\n   // update the spinner color and the spinner frames\n   spinner.with_frame_transform(s, ansi.green)\n   |&gt; spinner.with_frames(spinner.frames_from_list([&quot;a&quot;, &quot;s&quot;, &quot;d&quot;, &quot;f&quot;]))\n\n   // do some other stuff\n   \n   spinner.finish(s)\n }\n \n &lt;/details&gt;\nSynonyms:\nglitzer/spinner.with_frame_transform\nglitzer/spinner with_frame_transform","url":"glitzer/spinner.html#with_frame_transform"},{"doc":"glitzer/spinner","title":"with_frames","content":"pub fn with_frames(\n  spinner s: SpinnerStyle,\n  frames f: Frames,\n) -&gt; SpinnerStyle\n Set the frames of the spinner. Useful if you want to update the frames of\n an already running spinner.\nSynonyms:\nglitzer/spinner.with_frames\nglitzer/spinner with_frames","url":"glitzer/spinner.html#with_frames"},{"doc":"glitzer/spinner","title":"with_left_text","content":"pub fn with_left_text(\n  spinner s: SpinnerStyle,\n  text t: String,\n) -&gt; SpinnerStyle\n Set the left text of the spinner.\nSynonyms:\nglitzer/spinner.with_left_text\nglitzer/spinner with_left_text","url":"glitzer/spinner.html#with_left_text"},{"doc":"glitzer/spinner","title":"with_right_text","content":"pub fn with_right_text(\n  spinner s: SpinnerStyle,\n  text t: String,\n) -&gt; SpinnerStyle\n Set the right text of the spinner.\nSynonyms:\nglitzer/spinner.with_right_text\nglitzer/spinner with_right_text","url":"glitzer/spinner.html#with_right_text"},{"doc":"glitzer/spinner","title":"with_tick_rate","content":"pub fn with_tick_rate(\n  spinner s: SpinnerStyle,\n  ms ms: Int,\n) -&gt; SpinnerStyle\n Set the spinners tick rate in milliseconds.\nSynonyms:\nglitzer/spinner.with_tick_rate\nglitzer/spinner with_tick_rate","url":"glitzer/spinner.html#with_tick_rate"},{"doc":"glitzer/spinner","title":"glitzer/spinner","content":"","url":"glitzer/spinner.html"}]);